function [res,t] = dotree( tree, k, s )
% function res = dotree( tree, k, s )
% tree is an n by 3 array, each line for a derivation
% the line 17 10 5 means that seq17 is derived from seq10, seq5
% seq0 is the axiom [k]
%
% Example:
%     [res,seq] = dotree( derive3_4, 3, 4 )
%   where derive3_4 is 
%     [1     0     0 
%      2     0     1 
%      3     0     2 
%      4     3     3 
%      5     3     4 
%      6     5     5]
%   
%   Will yield res=[] and seq is the following:
%     seq{1} = [3]
%     seq{2} = [2 2]
%     seq{3} = [2 1 1]
%     seq{4} = [2 1]
%     seq{5} = [1 1]
%     seq{6} = [1]
%     seq{7} = []
%
%   NOTE: matlab starts arrays at index one, so the indices of seq are shifted
%         by one from what should be.
%
l = length( tree(:,1) );
t=cell(tree(l,1)+1,1);
t{1} = [k];
for i=1:l
  t{tree(i,1)+1} = step( s, t{tree(i,2)+1}, t{tree(i,3)+1} );
end
res = t{tree(l,1)+1};
